version 12.1

set more off

capture log close

log using redistribution.log, replace


*     ***************************************************************** *;
*     ***************************************************************** *;
*   File-Name:  redistribution.do										*;
*   Date:       December 17, 2014	                                    *;
*   Authors:    Chalmers and Dellmuth                                   *;
*   Purpose:    Replicate results for paper "Fiscal redistribution and  *;
*				public support for European integration"			    *;
*   Input File: redistribution.dta                                      *;
*   Output File:redistribution.log                     			        *;
*     ****************************************************************  *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*     Code variable nomiss to replicate results for sample used in paper*;
*     ****************************************************************  *;

mark sample
markout sample eum transfersc200713 sftotal2007131000cap identity identityex ///
edu disc partycohesion partyposition persex counex manualworker gdpc2010 ///
union trustngov age gender nutsreg country

tab sample


*     ****************************************************************  *;
*     Replicate Table 1													*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m1

*Model 2
gllamm eum sftotal2007131000cap identity identityxr ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m2

*Model 3
gllamm eum transfersc200713 identityex identityexxt ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m3

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m4

*Model 5
gllamm eum transfersc200713 edu eduxt ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m5

*Model 6
gllamm eum sftotal2007131000cap edu eduxr ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m6

*Model 7
gllamm eum transfersc200713 disc discxt ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m7

*Model 8
gllamm eum sftotal2007131000cap disc discxr ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m8

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m9

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr ///
transfersc200713 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m10

esttab m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 using table1.rtf, bic scalars(ll N) ///
b(%9.2f) se(%9.2f) starlevels(* .05 ** .01 *** .001) nodepvars


*     ****************************************************************  *;
*     Replicate Table 2													*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)
eststo m11

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit)
eststo m12

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit)
eststo m13

esttab m11 m12 m13 using table2.rtf, bic scalars(ll N) ///
b(%9.2f) se(%9.2f) starlevels(* .05 ** .01 *** .001) nodepvars


*     ****************************************************************  *;
*     Replicate Figure 1												*;
*     ****************************************************************  *;

*run int1.do, save file
*run int2.do, save file

*save output files as int1.gph and int2.gph

graph combine int1.gph int2.gph, ycommon graphregion(color(white))


*     ****************************************************************  *;
*     Replicate Figure 2												*;
*     ****************************************************************  *;

*run int5.do, save file
*run int6.do, save file

*save output files as int5.gph and int6.gph

graph combine int5.gph int6.gph, ycommon graphregion(color(white))


*     ****************************************************************  *;
*     Replicate Online Appendix											*;
*     ****************************************************************  *;


*Table A2
#delimit ;
logout, save(table-a2) word replace:
tabstat eum transfersc200713 sftotal2007131000cap identity identityex edu 
disc partycohesion partyposition persex counex manualworker gdpc2010 union 
trustngov age gender unrtn200710 unrt_nat_2010 unrtreg200710 unrtreg2010
transfersc2010 sfc1000_2010 transfersc200710 sfc1000_200710
if sample==1, stats(min mean max sd n) columns(statistics); 
#delimit cr


*Table A3
#delimit ;
logout, save(table-a3) word replace: corr transfersc200713 sftotal2007131000cap 
identity identityex edu disc partycohesion partyposition persex counex 
manualworker gdpc2010 union trustngov age gender if nomiss==1;
#delimit cr


*Table A4
gen nuts_upper = upper(nuts) 
logout, save(table-a4) word replace: table nuts_upper if nomiss==1, c(freq) col



*     ****************************************************************  *;
*     Replicate Table A6												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt unrtn200710 ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr unrtn200710 ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt unrtn200710 ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr unrtn200710 ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt unrtn200710 ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr unrtn200710 ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt unrtn200710 ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr unrtn200710 ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt unrtn200710 ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr unrtn200710 ///
transfersc200713 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A7												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap unrtn200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap unrtn200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 unrtn200710 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A8												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt unrt_nat_2010 ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr unrt_nat_2010 ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt unrt_nat_2010 ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr unrt_nat_2010 ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt unrt_nat_2010 ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr unrt_nat_2010 ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt unrt_nat_2010 ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr unrt_nat_2010 ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt unrt_nat_2010 ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr unrt_nat_2010 ///
transfersc200713 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A9												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap unrt_nat_2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap unrt_nat_2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 unrt_nat_2010 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A10												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt unrtreg200710 ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr unrtreg200710 ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt unrtreg200710 ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr unrtreg200710 ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt unrtreg200710 ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr unrtreg200710 ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt unrtreg200710 ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr unrtreg200710 ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt unrtreg200710 ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr unrtreg200710 ///
transfersc200713 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A11												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap unrtreg200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap unrtreg200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 unrtreg200710 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A12												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt unrtreg2010 ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)  

*Model 2
gllamm eum sftotal2007131000cap identity identityxr unrtreg2010 ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt unrtreg2010 ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr unrtreg2010 ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt unrtreg2010 ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr unrtreg2010 ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt unrtreg2010 ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr unrtreg2010 ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt unrtreg2010 ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr unrtreg2010 ///
transfersc200713 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A13												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap unrtreg2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap unrtreg2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 unrtreg2010 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A14												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt ///
identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr ///
identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt ///
identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr ///
identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt ///
identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr ///
identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt ///
identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr ///
identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt ///
identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr ///
identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A15												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 ///
transfersc200713 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 

*Model 11b
gllamm eum sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12b
gllamm eum sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13b
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 ///
sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 



*     ****************************************************************  *;
*     Replicate Table A16												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt ///
sftotal2007131000cap identityex edu disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr ///
transfersc200713 identityex edu disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt ///
sftotal2007131000cap identity edu disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr ///
transfersc200713 identity edu disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt ///
sftotal2007131000cap identity identityex disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr ///
transfersc200713 identity identityex disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt ///
sftotal2007131000cap identity identityex edu ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr ///
transfersc200713 identity identityex edu ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt ///
sftotal2007131000cap identity identityex edu disc ///
persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr ///
transfersc200713 identity identityex edu disc ///
persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A17												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 

*Model 11b
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12b
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13b
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 ///
transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 



*     ****************************************************************  *;
*     Replicate Table A18												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)  

*Model 2
gllamm eum sftotal2007131000cap identity identityxr ///
transfersc200713 identityex edu disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)  

*Model 3
gllamm eum transfersc200713 identityex identityexxt ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr ///
transfersc200713 identity edu disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr ///
transfersc200713 identity identityex disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr ///
transfersc200713 identity identityex edu ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt ///
sftotal2007131000cap identity identityex edu disc ///
partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr ///
transfersc200713 identity identityex edu disc ///
partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 



*     ****************************************************************  *;
*     Replicate Table A19												*;
*     ****************************************************************  *;

*Model 1
gllamm eum transfersc200713 identity identityxt ///
sftotal2007131000cap identityex edu disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sftotal2007131000cap identity identityxr ///
transfersc200713 identityex edu disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200713 identityex identityexxt ///
sftotal2007131000cap identity edu disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sftotal2007131000cap identityex identityexxr ///
transfersc200713 identity edu disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200713 edu eduxt ///
sftotal2007131000cap identity identityex disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sftotal2007131000cap edu eduxr ///
transfersc200713 identity identityex disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200713 disc discxt ///
sftotal2007131000cap identity identityex edu ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sftotal2007131000cap disc discxr ///
transfersc200713 identity identityex edu ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200713 partycohesion partycohesionxt ///
sftotal2007131000cap identity identityex edu disc ///
partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sftotal2007131000cap partycohesion partycohesionxr ///
transfersc200713 identity identityex edu disc ///
partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 


*     ****************************************************************  *;
*     Replicate Table A20												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition persex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 

*Model 11
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12b
gllamm eum transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13b
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 transfersc200713 sftotal2007131000cap ///
identity identityex edu disc ///
partycohesion partyposition counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 



*     ****************************************************************  *;
*     Replicate Table A21												*;
*     ****************************************************************  *;

gen identityxtransfersc2010= identity*transfersc2010
gen identityxsfc1000_2010 = identity* sfc1000_2010
gen identityexxtransfersc2010= identityex*transfersc2010
gen identityexxsfc1000_2010 = identityex* sfc1000_2010
gen eduxtransfersc2010= edu*transfersc2010
gen eduxsfc1000_2010 = edu* sfc1000_2010
gen discxtransfersc2010= disc*transfersc2010
gen discxsfc1000_2010 = disc* sfc1000_2010
gen partycxtransfersc2010= partycohesion*transfersc2010
gen partycxsfc1000_2010 = partycohesion* sfc1000_2010

*Model 1
gllamm eum transfersc2010 identity identityxtransfersc2010 ///
sfc1000_2010 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sfc1000_2010 identity identityxsfc1000_2010 ///
transfersc2010 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc2010 identityex identityexxtransfersc2010 ///
sfc1000_2010 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 
 
*Model 4
gllamm eum sfc1000_2010 identityex identityexxsfc1000_2010 ///
transfersc2010 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc2010 edu eduxtransfersc2010 ///
sfc1000_2010 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sfc1000_2010 edu eduxsfc1000_2010 ///
transfersc2010 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc2010 disc discxtransfersc2010 ///
sfc1000_2010 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sfc1000_2010 disc discxsfc1000_2010 ///
transfersc2010 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc2010 partycohesion partycxtransfersc2010 ///
sfc1000_2010 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sfc1000_2010 partycohesion partycxsfc1000_2010 ///
transfersc2010 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)


*     ****************************************************************  *;
*     Replicate Table A22												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc2010 sfc1000_2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc2010 sfc1000_2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit)

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 transfersc2010 sfc1000_2010 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit)  



*     ****************************************************************  *;
*     Replicate Table A23												*;
*     ****************************************************************  *;

gen identityxtransfersc200710= identity*transfersc200710
gen identityxsfc1000_200710 = identity* sfc1000_200710
gen identityexxtransfersc200710= identityex*transfersc200710
gen identityexxsfc1000_200710 = identityex* sfc1000_200710
gen eduxtransfersc200710= edu*transfersc200710
gen eduxsfc1000_200710 = edu* sfc1000_200710
gen discxtransfersc200710= disc*transfersc200710
gen discxsfc1000_200710 = disc* sfc1000_200710
gen partycxtransfersc200710= partycohesion*transfersc200710
gen partycxsfc1000_200710 = partycohesion* sfc1000_200710


*Model 1
gllamm eum transfersc200710 identity identityxtransfersc200710 ///
sfc1000_200710 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 2
gllamm eum sfc1000_200710 identity identityxsfc1000_200710 ///
transfersc200710 identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 3
gllamm eum transfersc200710 identityex identityexxtransfersc200710 ///
sfc1000_200710 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 4
gllamm eum sfc1000_200710 identityex identityexxsfc1000_200710 ///
transfersc200710 identity edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 5
gllamm eum transfersc200710 edu eduxtransfersc200710 ///
sfc1000_200710 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 6
gllamm eum sfc1000_200710 edu eduxsfc1000_200710 ///
transfersc200710 identity identityex disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 7
gllamm eum transfersc200710 disc discxtransfersc200710 ///
sfc1000_200710 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 8
gllamm eum sfc1000_200710 disc discxsfc1000_200710 ///
transfersc200710 identity identityex edu ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 9
gllamm eum transfersc200710 partycohesion partycxtransfersc200710 ///
sfc1000_200710 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 10
gllamm eum sfc1000_200710 partycohesion partycxsfc1000_200710 ///
transfersc200710 identity identityex edu disc ///
partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit)


*     ****************************************************************  *;
*     Replicate Table A24												*;
*     ****************************************************************  *;

*Model 11
gllamm eum transfersc200710 sfc1000_200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender if sample==1, i(nutsreg country) robust link(ologit) 

*Model 12
gllamm eum transfersc200710 sfc1000_200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
manualworker gdpc2010 if sample==1, i(nutsreg country) robust link(ologit) 

*Model 13
gllamm eum manualworker gdpc2010 manualworkerxgdpc2010 transfersc200710 sfc1000_200710 ///
identity identityex edu disc ///
partycohesion partyposition persex counex union ///
trustngov age gender ///
if sample==1, i(nutsreg country) robust link(ologit) 



*     ****************************************************************  *;
*     Replicate Figure C1												*;
*     ****************************************************************  *;

*run intc3.do


*     ****************************************************************  *;
*     Replicate Figure C2												*;
*     ****************************************************************  *;

*run intc4.do


*     ****************************************************************  *;
*     Replicate Figure C3												*;
*     ****************************************************************  *;

*run intc7.do


*     ****************************************************************  *;
*     Replicate Figure C4												*;
*     ****************************************************************  *;

*run intc8.do


*     ****************************************************************  *;
*     Replicate Figure C5												*;
*     ****************************************************************  *;

*run intc9.do


*     ****************************************************************  *;
*     Replicate Figure C6												*;
*     ****************************************************************  *;

*run intc10.do


*     ****************************************************************  *;
*     Replicate Figure C7												*;
*     ****************************************************************  *;

*run intc13.do


exit
