version 12.1
capture log close
set more off

*     ***************************************************************** *;
*     ***************************************************************** *;
*       Source:         Modified code from Brambor et al.               *;
*       File-Name:      intc7.do		                                *;
*       Date:           2014, December 18                               *;
*       Authors:        Chalmers and Dellmuth                           *;
*       Purpose:        Do-file to produce a marginal effect plot for   *;
*                       X after multilevel random-intercept model using *;
*                       ordered logistic regression 					*;
*       Input File:     redistribution.dta 	 	                        *;
*       Output File:    intc13.log		        			            *; 
*     ****************************************************************  *;
*     ****************************************************************  *;

#delimit;

log using mc13.log, replace;

estimates restore m13;
        
preserve;

set seed 339487731;

drawnorm MG_b1-MG_b21, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace;
            
noisily display "start";
   
local a=62 ;
while `a' <= 131 { ;

{;

scalar h_sf        = .2303391 ;  
scalar h_Control1  = .5639899 ; // mean
scalar h_Control2  = 917.7025 ; // mean
scalar h_Control3  = 1.78506  ; // mean
scalar h_Control4  = .6779102 ; // mean
scalar h_Control5  = 5.397984 ; // mean 
scalar h_Control6  = 1.04088  ; // mean 
scalar h_Control7  = 5.657393 ; // mean 
scalar h_Control8  = 5.428448 ; // mean
scalar h_Control9  = 3.068011 ; // mean 
scalar h_Control10 = .9252062 ; // mean
scalar h_Control11 = 0        ; // median (union membership)
scalar h_Control12 = .3821265 ; // mean
scalar h_Control13 = 49.89313 ; // mean 
scalar h_Control14 = 1        ; // median (gender) 
scalar h_constant1 = 1;
scalar h_constant2 = 1;
		 
	  
    generate x_betahat0 = MG_b1*h_sf
                            + MG_b2*`a'
                            + MG_b3*h_sf*`a'
                            + MG_b4*h_Control1
                            + MG_b5*h_Control2
                            + MG_b6*h_Control3
                            + MG_b7*h_Control4
                            + MG_b8*h_Control5
                            + MG_b9*h_Control6
                            + MG_b10*h_Control7
                            + MG_b11*h_Control8
                            + MG_b12*h_Control9
                            + MG_b13*h_Control10 
                            + MG_b14*h_Control11 
                            + MG_b15*h_Control12  
                            + MG_b16*h_Control13  
                            + MG_b17*h_Control14  
                            + MG_b20*h_constant1 
                            + MG_b21*h_constant2;
        
    generate x_betahat1 = MG_b1*(h_sf)
                            + MG_b2*`a'
                            + MG_b3*(h_sf+1)*`a' // counterfactual scenario where manualworker increases by 1
                            + MG_b4*h_Control1
                            + MG_b5*h_Control2
                            + MG_b6*h_Control3
                            + MG_b7*h_Control4
                            + MG_b8*h_Control5
                            + MG_b9*h_Control6
                            + MG_b10*h_Control7
                            + MG_b11*h_Control8
                            + MG_b12*h_Control9
                            + MG_b13*h_Control10  
                            + MG_b14*h_Control11 
                            + MG_b15*h_Control12  
                            + MG_b16*h_Control13  
                            + MG_b17*h_Control14  
                            + MG_b20*h_constant1 
                            + MG_b21*h_constant2;
                             
gen prob0=normal(MG_b19-x_betahat0)-normal(MG_b18-x_betahat0); // see Wooldridge eq. 15.88,	yields P(y=1|x)
gen prob1=normal(MG_b19-x_betahat1)-normal(MG_b18-x_betahat1); // MG_b19 treated as cut 2, MV_b18 treated as cut 1
gen diff=prob1-prob0;    

    egen probhat0 =mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);    
           
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi;  

    _pctile prob0, p(2.5,97.5) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  
   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi');
   
    };      
    
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat;
    
    local a=`a'+ 1;
    
    display "." _c;
    
} ;

display "";

postclose mypost;

*     ****************************************************************  *;                                  
*       Call on posted quantities of interest                           *;
*     ****************************************************************  *;

restore;

merge using sim.dta;

gen yline = 0;
gen MV    = _n+60 ;
replace MV= . if _n > 130;

log close;
#delimit cr

preserve

drop if _n>70

sum MV
#delimit ;
graph twoway line diff_hat MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||  line yline MV,  clwidth(thin) clcolor(black) clpattern(solid)
        ||  line diff_lo MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line diff_hi MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(60(10)130, nogrid labsize(2)) 
            ylabel(, axis(1) nogrid labsize(2)) 
            yscale(noline)  xscale(noline) legend(off)
            yline(0, lcolor(black)) 
            xtitle(GDP, size(2.5))
            ytitle("Marginal effect of being a manual worker on support", size(2.5))
            xsca(titlegap(4)) ysca(titlegap(4)) 
            scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));
#delimit cr

drop prob_hat0-MV
